dojo.provide("com.ibm.pb.contextMenu.ShadowContextMenuLoader");

dojo.require("com.ibm.pb.logging.Loggable");

/**
 * Creates a context menu loader that shadows an existing context menu by its specific ID.  This loader
 * can be registered to a different context menu ID in the system, but will retrieve its contents
 * internally from the context menu that it shadows.  This module can be used to create nested structures
 * of context menu loaders where a base loader may be registered to a particular context menu ID in
 * the system and the specific instances mapped to different IDs may get the same data from the base
 * loader but provide a place for custom contributions and onChange events.  Any contributions to the
 * shadowed menu will be reflected here, and any update event in the base menu will be reflected here too.
 */
dojo.declare("com.ibm.pb.contextMenu.ShadowContextMenuLoader", [com.ibm.mashups.builder.model.ContextMenuLoader, com.ibm.pb.logging.Loggable], {
	
	builderFactory: com.ibm.mashups.builder.model.Factory,
	shadowedMenuId: "",
	
	constructor: function(contextMenuId) {
		this.shadowedMenuId = contextMenuId;
		this.builderFactory.getContextMenuModel().registerListener(contextMenuId, this, "onChange");
		
	},
	getItems: function(/*String*/ contextMenuId, /*String*/ targetResourceId, /*String*/ targetResourceType, /*Object*/ someObject) {
		return this.builderFactory.getContextMenuModel().getContextMenuDeferred(this.shadowedMenuId, targetResourceId, targetResourceType, someObject);
	}
});
	