dojo.provide("com.ibm.pb.screen.VariableGridZone");

dojo.require("com.ibm.pb.screen.GridZone");

dojo.declare("com.ibm.pb.screen.VariableGridZone",
	com.ibm.pb.screen.GridZone,
	{
		// summary: A module that represents a zoned grid over a particular DOM node
		//		and provides an API for determining which zone in the grid a set of
		//		coordinates resides in.  The grid is variable, meaning that the overall
		// 		grid is rectangular in shape just like the GridZone, but that each row
		//		and column in the grid may have a variable size based on a ratio
		//		of the specified size to the total size of all the elements in the given
		//		axis.
		
		_getIdx: function(c, abs, ratios) {
			if(c < 0 || c >= abs) return -1;
			var num = ratios.length, pos = 0, i = 0, zSize;
			for(; i < ratios.length; i++) {
				zSize = abs * ratios[i];
				if((c - pos) <= zSize) {
					break;
				}
				pos += zSize;
			}
			return i;
		},
		_getRow: function(y) {
			return this._getIdx(y, dojo.style(this.node, "height"), this.rowRatios);
		},
		_getCol: function(x) {
			return this._getIdx(x, dojo.style(this.node, "width"), this.colRatios);
		},
		rezone: function(params) {
			this.rowRatios = this._getRatios(params.rowsDef.slice());
			this.rows = this.rowRatios.length;
			this.colRatios = this._getRatios(params.colsDef.slice());
			this.cols = this.colRatios.length;
		},
		_getRatios: function(arr) {
			var abs = 0;
			for(var i = 0; i < arr.length; i++) {
				abs += arr[i];
			}
			for(var i = 0; i < arr.length; i++) {
				arr[i] /= abs;
			}
			return arr;
		},
		_getZoneSpotDims: function(box, rowIdx, colIdx) {
			return {
				w: box.w * this.colRatios[colIdx], 
				h: box.h * this.rowRatios[rowIdx]
			};
		}
	}
);
