/* Copyright IBM Corp. 2015  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.strategy.PageLoadAheadStrategy");

dojo.require("com.ibm.mashups.enabler.strategy.Strategy");

//<INTERFACE>
/**
 * Interface that defines a load ahead mulipart strategy for loading artifacts
 * of a navigation node. When applied to a navigation model, the layout model,
 * theme, and current user may be preloaded via a multipart request
 * if multipart is supported by the server.
 * @ibm-api
 * @ibm-module CoreModel
 */
dojo.declare("com.ibm.mashups.enabler.strategy.PageLoadAheadStrategy", com.ibm.mashups.enabler.strategy.Strategy, {
    /**
     * @param {boolean} loadAheadLayoutModel if the layout model should be
     * preloaded when a navigation node is load. Must not be <code>null</code>.
     * @param {boolean} loadAheadTheme if the theme should be
     * preloaded when a navigation node is load. Must not be <code>null</code>.
     * @param {boolean} loadAheadUser if the user should be
     * preloaded when a navigation node is load. Must not be <code>null</code>.
     */
    constructor: function(loadAheadLayoutModel, loadAheadTheme, loadAheadUser){
    },
    
    /**
     * Returns if the layout model should be loaded after a navigation node is
     * loaded
     * @return {Boolean} <code>true</code> if the layout model should be
     *                   preloaded, <code>false</code> otherwise
     */
    isLoadAheadLayoutModel: function(){
        return this.loadAheadLayoutModel;
    },
    
    /**
     * Returns if a navigation node's theme should be loaded after the node
     * is loaded
     * @return {Boolean} <code>true</code> if the theme should be
     *                   preloaded, <code>false</code> otherwise
     */
    isLoadAheadTheme: function(){
        return this.loadAheadTheme;
    }
});
//</INTERFACE>
dojo.require("com.ibm.mm.enabler.strategy.PageLoadAheadStrategyImpl");
