/* Copyright IBM Corp. 2015  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.livetext.LivetextBatchModel");

/**
   This is the tag processor API. When a match tag is found by the livetext service according to the configuration, the service
   will hand the all DOM nodes to the tag processor which matches the criteria. Each tag processor must implement this interface. Each processor must also provide a 
   non-parameter constructor in addition to the processTag method. The non-parameter constructor is to ensure that the livetext service
   can create an instance of the implementation class without providing any more information. <p />    

   @ibm-api
   @ibm-module iWidget
  */ 
dojo.declare("com.ibm.mashups.livetext.LivetextBatchModel", null, 
{
	/**
	* The entry point of a tag processor. When a tag is found, the service will dynamically load the module which was designed to process
	* that type of tags, then create an instance of that tag module class if it has not been created, then call this method and hand the 
	* control to the tag module.
 	* @param {DOMNode[]} nodes The livetext DOM nodes to be processed. Must not be <code>null</code>.
 	* @param {com.ibm.mashups.livetext.ConfigEntry} configEntry The configuration enrty for the handler. This will be required in case we have one hanlder for multiple matching criteria <code>null</code>.
 	* @type void
 	*/	
	processTag: function(/*DOMNode[]*/nodes, configEntry) {
	},
    /**
    * The entry point of a tag processor (unchanging). When a tag is found, the service will dynamically load the module which was designed to process
    * that type of tags, then create an instance of that tag module class if it has not been created, then call this method and hand the 
    * control to the tag module.
    * @param {DOMNode[]} nodes The livetext DOM node to be &quot;unprocessed&quot;. Must not be <code>null</code>.
    * @type void
    */
    unprocessTag: function(/*DOMNode[]*/nodes) {
    }
});
